@@ -112,7 +112,7 @@ class Elbow:
 		plt.title('The Elbow Method showing the optimal k')
 		plt.show()
 
-	def get_optimal_number_of_clusters(self, by='silhouette_score'):
+	def get_optimal_number_of_clusters(self, by='silhouette'):
 		"""
 		:param str by: can be 'inertia' or 'distortion'
 		:rtype: int
@@ -124,7 +124,7 @@ class Elbow:
 		elif by.startswith('distort'):
 			y_dictionary = self._distortions
 		else:
-			y_dictionary = self._silhouette_scores
+			y_dictionary = {key: -value for key, value in self._silhouette_scores.items()}
 
 		y1, y2 = y_dictionary[x1], y_dictionary[x2]
 		distances = []
@@ -142,7 +142,11 @@ class Elbow:
 		"""
 		:rtype: int
 		"""
-		return max(
+		def _max(*args):
+			return max(*[x for x in args if x is not None])
+
+		return _max(
+			self.get_optimal_number_of_clusters(by='silhouette'),
 			self.get_optimal_number_of_clusters(by='inertia'),
 			self.get_optimal_number_of_clusters(by='distortion')
 		)
